function y = LaserCW(UnmodulatedPower,Linewidth)
%
% Usage: y = LaserCW(UnmodulatedPower,Linewidth)
%
% Purpose = This module produces a continuous wavw (CW) optical signal.
%
% Input Signal = Not required.
% Output Signal(y) = Continuous (unmodulated) Wave Optical Signal
%
% === Physical Parameters === 
% UnmodulatedPower = 1e-3 (default) ;  % [W]
% Linewidth = 10e6 (default);     %[Hz]
%
% (global variables) DataLength SampleRate 
%
%------------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%=======================================================================
global DataLength SampleRate 

if nargin<2, Linewidth = 10e6; end
if nargin==0, 
    UnmodulatedPower = 1e-3;% [W]
end

white_noise = sqrt(2*pi*Linewidth)*randn(1,DataLength);
y = sqrt(UnmodulatedPower)*exp(1i*cumsum(white_noise)/SampleRate);
