function y = OpticalFilter_Flattop(Optical_input,FilterCenter,BW_3dB,n_filter)
%
% Usage: y = OpticalFilter_Flattop(Optical_input,FilterCenter,BW_3dB,n_filter)
% 
% Purpose = This module represents an optical filter with a flattop (super-Gaussian) shape.
%
% Input Signal(Optical_input) = Optical Signal 
% Output Signal(y) = Optical Signal 
%
% ==== Physical Parameters ===== 
% FilterCenter = Deviation in [Hz] from the 'Ref_Frequency' [Hz]
%              = 0  (default)
% BW3dB = 3dB Bandwidth [Hz]
%       = 4*BitRate (default)
% n_filter = super gaussain factor (>1 for super Gaussian, =1 if Gaussian)
%          = 2 (default)
%
%   (global variables) f_sym BitRate
%
% Note1) Insertion Loss is NOT included. (IL can be modeled separately using function 'Attenuator'.)
% Note2) FilterCenter = 0 corresponds to 'Ref_frequency'.  
%        Physical frequency = 'Ref_frequency' + 'f_sym'
% Note3) abs(FilterCenter) should be less than Fs/2, that is, less than max(f_sym).
%
%------------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%====================================================================================
global f_sym BitRate

if nargin <4
    n_filter=2;   
end    
if nargin<3,
 BW_3dB = 4*BitRate;
end
if nargin<2,
   FilterCenter = 0;
end

%======== Define the filter transfer function ================
% Magnitude transfer function for optical field
T_tranf = exp(-log(sqrt(2))*(abs((f_sym-FilterCenter))/(0.5*BW_3dB)).^(2*n_filter));
%=====================================================================================

%========= Filtering input signal with the defined optical filter =================
E_out_f = fft(Optical_input);
Filtered = fftshift(T_tranf).*E_out_f;%

%====== Filtered Optical Field in time domain
y = ifft(Filtered);
