function [y1,y2,y3,y4] = PowerSplitter1_4(Input_optical,alpha1,alpha2,alpha3)
%
% Usage: [y1,y2,y3,y4] = PowerSplitter1_4(Input_optical,alpha1,alpha2,alpha3)
%
% Purpose = This module splits an optical input signal into four output signals.
%
% Input Signal(Input_optical) = Optical Filed Signal
%
% Output Signal(y1) = Optical Field Signal at port 1, phase difference=0
% Output Signal(y2) = Optical Field Signal at port 2, phase difference=90
% Output Signal(y3) = Optical Field Signal at port 3, phase difference=90
% Output Signal(y4) = Optical Field Signal at port 4, phase difference=180
%
% === Physical Parameter ===
% alpha1,alpha2,alpha3 = coupling coefficient [0,1] 
%                      = 0.5 (default)
%
%------------------------------------------------------------
% $ Revision: 1.0 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%===============================================================================

if nargin<4, 
    alpha3=0.5;
end
if nargin<3, 
    alpha2=0.5;
end
if nargin<2, 
    alpha1=0.5;
end

[yyl,yy2] = CrossCoupler(Input_optical,0,alpha1);

[y1,y2] = CrossCoupler(yyl,0,alpha2);
[y3,y4] = CrossCoupler(yy2,0,alpha3);
