function y = PulseGaussianElectrical(info_bits,Amplitude,FWHM,GaussianOrder,ExcessPulseSlots,CenterPosition)
%
% Usage : 
%  y = PulseGaussianElectrical(info_bits,Amplitude,FWHM,GaussianOrder,ExcessPulseSlots,CenterPosition)
%
% Purpose = This function generates Gaussain or super-Gaussian electrical pulses,
%           modulated by a bit sequence.
%
% Input (info_bits) = bit sequence 
% Output (y) = Gaussian, or super-Gaussian electrical pulse
%
% ===== Physical Parameters ======
% Amplitude ; [a.u.], default = 1 
% FWHM, Full width at half maximum amplitude; [sec] default = 1/3/BitRate;
% GaussianOrder ; Order of super-Gaussain function, default = 1 (Gaussian)
% ExcessPulseSlots; Number of extra bit slot to consider neighboring bits, default = 3;
% CenterPosition ; Relative position of the pulse center wrt bit frame  %[-0.5 0.5] default = 0 (center)
%
% (global variables) BitRate Bits samplesperbit SampleRate 
%
% Note) y (Single Pulse) = Amplitude*exp(-0.5*log(2)*abs(2*t_bits/FWHM).^(2*GaussianOrder));
%
%------------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%==========================================================================================
global BitRate Bits samplesperbit SampleRate 

if nargin<6,
   CenterPosition = 0;% 
end
if nargin<5,
   ExcessPulseSlots = 3;% 
end
if nargin<4,
   GaussianOrder = 1;% 
end
if nargin<3,
   FWHM = 1/3/BitRate;% 
end
if nargin<2,
   Amplitude = 1;% 
end

%--------------------------------------------------------------------------
Tb = 1/BitRate;
t_b = -ExcessPulseSlots*Tb:1/SampleRate:(ExcessPulseSlots*Tb-1/SampleRate);
t_bits = t_b - CenterPosition*Tb;
GaussP = Amplitude*exp(-0.5*log(2)*abs(2*t_bits/FWHM).^(2*GaussianOrder)); % Single Pulse  

GaussT = info_bits'*GaussP;

% Now for delayed pulses

   for k=1:Bits

     y1(k,:)=[zeros(1,samplesperbit*(k-1)) GaussT(k,:) zeros(1,(Bits-k)*samplesperbit)];
       
   end
   
pulses1 = sum(y1);   

r_Excess = ExcessPulseSlots - 0.5; 

y = pulses1((r_Excess*samplesperbit+1):(length(pulses1)-r_Excess*samplesperbit));

