function y = PulseSechantOptical(info_bits,PeakPower,FWHM,ExcessPulseSlots,CenterPosition) 
% 
% Usage : y = PulseSechantOptical(info_bits,PeakPower,FWHM,ExcessPulseSlots,CenterPosition)
%
% Purpose = This function generates optical sechant(hypobolic secant) pulses,modulated by a bit sequence.
%
% Input (info_bits) = bit sequence
% Output (y) = Sechant shaped optical (field) pulse
%
% ===== Physical Parameters ======
% PeakPower ; [W] default = 1e-3;
% FWHM, Full width at half maximum power [sec], default = 1/3/BitRate;
% ExcessPulseSlots; Number of extra bit slots for each side to consider overlapping 
%                         with neighboring bits, default = 3;
% CenterPosition ; Relative position of the pulse peak wrt bit frame  %[-0.5 0.5], default = 0 (center)
%     
% (global variables) BitRate Bits samplesperbit SampleRate 
%
% Note) y (Single Pulse) = sqrt(PeakPower)./cosh(2*t_bits/FWHM*acosh(sqrt(2))); 
% 
%------------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%==========================================================================================
global BitRate Bits samplesperbit SampleRate

if nargin<5,
   CenterPosition = 0;% 
end
if nargin<4,
   ExcessPulseSlots = 3;% 
end
if nargin<3,
   FWHM = 1/3/BitRate;% 
end
if nargin<2,
   PeakPower = 1e-3;% [W]
end

%--------------------------------------------------------------------------

Tb = 1/BitRate;
t_b = -ExcessPulseSlots*Tb:1/SampleRate:(ExcessPulseSlots*Tb-1/SampleRate);
t_bits = t_b - CenterPosition*Tb;

SechantP = sqrt(PeakPower)./cosh(2*t_bits/FWHM*acosh(sqrt(2)))*exp(1i); % Single Pulse  
% exp(ii) will make SechantP a complex.
SechantT = info_bits'*SechantP;

% Now for delayed pulses

   for k=1:Bits

     y1(k,:)=[zeros(1,samplesperbit*(k-1)) SechantT(k,:) zeros(1,(Bits-k)*samplesperbit)];
       
   end
   
pulses1 = sum(y1);   

r_Excess = ExcessPulseSlots - 0.5; 

y = pulses1((r_Excess*samplesperbit+1):(length(pulses1)-r_Excess*samplesperbit));

