function y = Rx_APD(E_optical,Responsivity,AvalacheMul,IonizationCoeff,ShotNoiseFactor,ThermalNoiseDen,...
                DarkCurrMult,DarkCurrNonMult,FilterOrder,BW3dB)  
%
% Usage : y = Rx_APD(E_optical,Responsivity,AvalacheMul,IonizationCoeff,ShotNoiseFactor,ThermalNoiseDen,...
%                DarkCurrMult,DarkCurrNonMult,FilterOrder,BW3dB)  
%                
% Purpose = This module acts as a receiver consisted with a APD and a low pass Bessel filter.
%
% Input Signal (E_optical) = Received Optical Signal 
% Output Signal (y) = Electrical Signal 
%
% === Physical Parameters  === 
% Responsivity  = 1.0 [A/W], [0,2]
% ThermalNoiseDen = 1e-22 [A^2/Hz], Power Spectral Density of Thermal noise 
% DarkCurrMult = 0 [A], [0,10e-6]
% DarkCurrNonMult = 0 [A], [0.10e-6]
% AvalacheMul = 1   [1,1000]
% IonizationCoeff = 1  [1e-3, 1]
% ShotNoiseFactor = 1   (1 if shot noise included, 0 if not)
% FilterOrder = positive integer
% BW3dB [Hz] = 3dB Bandwidth of Electrical Low Pass Filter (positive frequency)
%
%------------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%===============================================================================
global BitRate 

if nargin<10,
   BW3dB = 0.7*BitRate;
end
if nargin<9,
   FilterOrder = 3;
end
if nargin<8,
   DarkCurrNonMult = 0;% [A]
end
if nargin<7,
    DarkCurrMult = 0; % [A]
end
if nargin<6,
    ThermalNoiseDen = 1e-22;% [A^2/Hz];
end
if nargin<5,
   ShotNoiseFactor = 1;
end
if nargin<4,
   IonizationCoeff = 1;
end
if nargin<3,
   AvalacheMul = 1; 
end
if nargin<2, 
  Responsivity = 1.0; %[A/W]
end
%===============================================================================

i_apd = PhotoDiode_APD(E_optical,Responsivity,AvalacheMul,IonizationCoeff,ShotNoiseFactor,ThermalNoiseDen,...
                DarkCurrMult,DarkCurrNonMult);

%======== Filtering by Bessel Low-pass filter ==============
y = E_FilterLPBessel(i_apd,FilterOrder,BW3dB); 

