function [Syn_out,ref_pulse] = Synchronizer(InputElectrical,info_bit)
%
% Usage: [Syn_out,ref_pulse] = Synchronizer(InputElectrical,info_bit)
%
% Purpose = This module is to calculate synchronized input signal with ref_pulse
%
% Input1(InputElectrical) = Single channel signal (Ex.)photo-detected electrical signal), Size = [1 x DataLength]
% Input2(info_bit) = Bit sequence sent at the transmitter
%
% Output1(Syn_out) = Synchronized version of InputElectrical  
% Output2(ref_pulse) = Reference pulse
%
%==== Simulation Parameters ===============
%  None  
%
% Note 1) When the bit number is relatively small ( < 128), this module 'Synchronizer' may not work properly. 
%
%----------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%----------------------------------------------------------
%
%======================================================================================================================
global DataLength

%=== Generate reference pulse to obtain dealy time due to group delay ========
ref_pulse = NRZCoder(info_bit)'; %
corr = xcorr(ref_pulse,InputElectrical); % reference is 'ref_pulse'      (will work with Matlab 6.5)
delay_index = find(corr == max(corr));

%=== Generate new input signal synchronized with ref_pulse ==========  

if delay_index >= DataLength   ;%'InputElectrical' leads 'ref_pulse' 
   
   dd = delay_index - DataLength;
   Syn_out = [InputElectrical((DataLength-dd+1):DataLength), InputElectrical(1:DataLength-dd)];

else                         %'InputElectrical' lags 'ref_pulse'  
   
   dd =  DataLength-delay_index;
   Syn_out = [InputElectrical(dd+1:DataLength), InputElectrical(1:dd)];

end
