function y = WDM_Mux_Flattop(Optical_composite,BW_3dB,n_filter,IL)  
%
% Usage: y = WDM_Mux_Flattop(Optical_composite,BW_3dB,n_filter,IL)
%
% Purpose = This module represents a Mux with Flattop(super-Gaussian) shaped optical filters.
%
% Input Signal(Optical_composite) = (Composite) Optical Signal (size = [ChannelNumber x DataLength])
% Output Signal(y) = Optical Signal (size = [1 x DataLength])
%
% ==== Physical Parameters ===== 
%   BW_3dB = 3dB bandwidth [Hz]
%          = 4*BitRate (default)
%   n_filter = super gaussain factor (>1 for super Gaussian, =1 if Gaussian)
%            = 2 (default)
%   IL  = insertion loss [dB]
%       = 3 (default) 
%
% Note1) All the filter characteristicas (shape, bandwidth, and IL) are assumed equal.
% Note2) Filter spacing is uniform.
%
%----------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%            ------ Mux Characteristics are defined by 'OpticalFilter_Flattop'
%------------------------------------------------------------
%====================================================================================
global  ChannelNumber ChannelSpacing BitRate

if nargin<4,
   IL = 3;
end
if nargin<3,
  n_filter = 2 ;
end
if nargin<2,
 BW_3dB = 4*BitRate;
end


[a,b] = size(Optical_composite);

if a == 1  ; %single channel case
   Optical_input = Optical_composite;
else
   Optical_input = sum(Optical_composite); %Ideal Muxing
end

FilterNumber = ChannelNumber;
FilterSpacing = ChannelSpacing;

if FilterNumber == 1
   
    x = OpticalFilter_Flattop(Optical_input,0,BW_3dB,n_filter);
    y = Attenuator(x,IL);
    
else
    
    for k = 1:FilterNumber
    
          
          FilterCenter(k) = FilterSpacing*(k - (ChannelNumber+1)/2);
          x(k,:) = OpticalFilter_Flattop(Optical_input,FilterCenter(k),BW_3dB,n_filter);%     
       
     end  
     
     filtered_x = sum (x);
     y = Attenuator(filtered_x,IL);
      
 end    
    
