function y = infobits_Alternate(PreSpaces,PostSpaces)
%
% Usage: y = infobits_Alternate(PreSpaces,PostSpaces)
%
% Purpose = This module generates an alternating bit sequences except 'PreSpaces' and 'PostSpaces'.
%
% Input Signal = Not required.
% Output Signal = Alternating bit sequence
%
% === Parameters  =====
% PreSpaces = Number of leading zero bits 
%           = 2 (default)
% PostSpaces = Number of trailing zero bits
%            = 2 (default)
%
% Bits(bit number) should be larger than (PreSpaces+PostSpaces).
%
%----------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%===============================================================================
global Bits

if nargin<2,
   PostSpaces = 2;
end

if nargin<1,
   PreSpaces = 2;
end

nn = Bits-PreSpaces-PostSpaces;
if nn <= 0,fprintf('Bits(bit number) should be larger than (PreSpaces+PostSpaces)!'); return; end

x = 0:pi:pi*(nn-1);
alter_seq = 0.5*(1+cos(x));

y = [zeros(1,PreSpaces) alter_seq zeros(1,PostSpaces)];
